Index: trunk/MagicSoft/Simulation/Detector/Camera/creadparam.cxx
===================================================================
--- trunk/MagicSoft/Simulation/Detector/Camera/creadparam.cxx	(revision 1225)
+++ trunk/MagicSoft/Simulation/Detector/Camera/creadparam.cxx	(revision 1231)
@@ -19,7 +19,7 @@
 //=
 //= $RCSfile: creadparam.cxx,v $
-//= $Revision: 1.14 $
+//= $Revision: 1.15 $
 //= $Author: blanch $ 
-//= $Date: 2002-02-28 15:07:23 $
+//= $Date: 2002-03-04 17:15:51 $
 //=
 //=//////////////////////////////////////////////////////////////////////
@@ -99,5 +99,5 @@
 static int Write_McTrig = FALSE;
 static int Write_McFadc = FALSE;
-static int Write_RawEvt = FALSE;
+static int Write_RawEvt = TRUE;
 static int Write_All_Data = FALSE;
 static int Select_Energy = TRUE;
@@ -389,5 +389,5 @@
       break;
 
-    case read_phe_all:        //@< to read PHE files from write_all_images
+    case read_phe_all:        //@< to read PHE files from write_all_events
           
       // change boolean value
@@ -396,5 +396,5 @@
       break;
 
-    case write_all_images:    //@< to write ALL the images
+    case write_all_events:    //@< to write ALL the images
           
       // change boolean value
@@ -421,4 +421,11 @@
       // change boolean value
       Write_McFadc = TRUE;
+
+      break;
+
+    case nowrite_RawEvt:    //@< to write the McFadc info
+          
+      // change boolean value
+      Write_RawEvt = FALSE;
 
       break;
@@ -976,5 +983,5 @@
 // @name get_read_phe_all
 //                                                
 // @desc get whether we will read PHE files, with write_all_images
 //
 // @return  TRUE: we'll do it; FALSE: we won't
@@ -994,5 +1001,5 @@
 
 //!-----------------------------------------------------------
-// @name write_all_images
+// @name write_all_events
 //                                                
 // @desc write all images to .phe, even those without trigger
@@ -1006,5 +1013,5 @@
 //!@{
 int
-get_write_all_images(void)
+get_write_all_events(void)
 {
   return ( Write_All_Images );
@@ -1339,4 +1346,8 @@
 //
 // $Log: not supported by cvs2svn $
+// Revision 1.14  2002/02/28 15:07:23  blanch
+// Small changes have been done to introduce thes step variable for the
+// discriminator threshold in the trigger loop mode.
+//
 // Revision 1.13  2002/01/18 17:43:08  blanch
 // Three new commands have been added: fadc_noise, trig_noise and
@@ -976,5 +983,5 @@
 // @name get_read_phe_all
 //                                                
-// @desc get whether we will read PHE files, with write_all_images
+// @desc get whether we will read PHE files, with write_all_events
 //
 // @return  TRUE: we'll do it; FALSE: we won't
